from enum import Enum

class InvokeUnlock_data_invokeStatus(str, Enum):
    WAITING = "WAITING",
    RUNNING = "RUNNING",
    COMPLETED = "COMPLETED",
    REJECTED = "REJECTED",
    UNKNOWN = "UNKNOWN",
    TIMEOUT = "TIMEOUT",
    CONNECTION_FAILURE = "CONNECTION_FAILURE",
    VEHICLE_IN_SLEEP = "VEHICLE_IN_SLEEP",
    UNLOCK_TIME_FRAME_PASSED = "UNLOCK_TIME_FRAME_PASSED",
    UNABLE_TO_LOCK_DOOR_OPEN = "UNABLE_TO_LOCK_DOOR_OPEN",
    EXPIRED = "EXPIRED",
    SENT = "SENT",
    NOT_SUPPORTED = "NOT_SUPPORTED",
    CAR_IN_SLEEP_MODE = "CAR_IN_SLEEP_MODE",
    DELIVERED = "DELIVERED",
    DELIVERY_TIMEOUT = "DELIVERY_TIMEOUT",
    SUCCESS = "SUCCESS",
    CAR_TIMEOUT = "CAR_TIMEOUT",
    CAR_ERROR = "CAR_ERROR",
    NOT_ALLOWED_PRIVACY_ENABLED = "NOT_ALLOWED_PRIVACY_ENABLED",
    NOT_ALLOWED_WRONG_USAGE_MODE = "NOT_ALLOWED_WRONG_USAGE_MODE",
    INVOCATION_SPECIFIC_ERROR = "INVOCATION_SPECIFIC_ERROR",

